@@ -13,9 +13,10 @@
   packageStartupMessage("**--------------------------------------------------------**")
   packageStartupMessage("** CovTools")
   packageStartupMessage("**  - Geometric & Statistical Tools for Covariance Matrices.")
+  packageStartupMessage("** ")
   packageStartupMessage("** Version    : ",this.version,"      (",this.year,")",sep="")
-  packageStartupMessage("** Author     : Kyoungjae Lee, Lizhen Lin, and Kisung You")
-  packageStartupMessage("** Maintainer : Kisung You (kyoustat@gmail.com)")
+  packageStartupMessage("** Authors    : Kyoungjae Lee, Lizhen Lin, and Kisung You")
+  packageStartupMessage("** Maintainer : Kisung You (kisungyou@outlook.com)")
   packageStartupMessage("**")
   packageStartupMessage("** Please share any bugs or suggestions to the maintainer.")
   packageStartupMessage("**--------------------------------------------------------**")
